# Test Project

This is a test project to verify spec-check works with pyproject.toml configuration.

## Features

- Configuration via pyproject.toml
- Installable via pip
- Works from venv

## Links

- [Internal link](./docs/guide.md)
- [Example](https://example.com/)
